@@ -1,7 +1,7 @@
 from enum import Enum
 
 
-LATEST_SOUTH_MIGRATION_ID = 174
+LATEST_SOUTH_MIGRATION_ID = 173
 #  Migration 174 deletes some fields, which were already not present in the
 #  models of the threedi-modelchecker. Therefore we can both accept migration
 #  173 and 174.
@@ -173,3 +173,26 @@ class InflowType(Enum):
     NO_INFLOW = 0
     IMPERVIOUS_SURFACE = 1
     SURFACE = 2
+
+
+class OffOrStandard(Enum):
+    OFF = 0
+    STANDARD = 1
+
+
+class FrictionShallowWaterDepthCorrection(Enum):
+    OFF = 0
+    MAX_AVERAGE_CHANNEL_BASED = 1
+    LINEARIZED = 2
+    LINEARIZED_WEIGHTED_AVERAGED = 3
+
+
+class LimiterSlopeXArea(Enum):
+    OFF = 0
+    HIGHER_ORDER_SCHEME = 1
+    UPWIND = 2
+    DEPTH_DEPENDED = 3
+
+
+class IntegrationMethod(Enum):
+    EULER_IMPLICIT = 0
