@@ -369,23 +369,27 @@ class NumericalSettings(Base):
     convergence_cg = Column(Float)
     convergence_eps = Column(Float)
     flow_direction_threshold = Column(Float)
-    frict_shallow_water_correction = Column(Integer)
+    frict_shallow_water_correction = Column(
+        IntegerEnum(constants.FrictionShallowWaterDepthCorrection)
+    )
     general_numerical_threshold = Column(Float)
-    integration_method = Column(Integer)
-    limiter_grad_1d = Column(Integer)
-    limiter_grad_2d = Column(Integer)
-    limiter_slope_crossectional_area_2d = Column(Integer)
-    limiter_slope_friction_2d = Column(Integer)
+    integration_method = Column(IntegerEnum(constants.IntegrationMethod))
+    limiter_grad_1d = Column(IntegerEnum(constants.OffOrStandard))
+    limiter_grad_2d = Column(IntegerEnum(constants.OffOrStandard))
+    limiter_slope_crossectional_area_2d = Column(
+        IntegerEnum(constants.LimiterSlopeXArea)
+    )
+    limiter_slope_friction_2d = Column(IntegerEnum(constants.OffOrStandard))
     max_nonlin_iterations = Column(Integer)
-    max_degree = Column(Integer, nullable=False)
+    max_degree = Column(Integer)
     minimum_friction_velocity = Column(Float)
     minimum_surface_area = Column(Float)
-    precon_cg = Column(Integer)
+    precon_cg = Column(IntegerEnum(constants.OffOrStandard))
     preissmann_slot = Column(Float)
     pump_implicit_ratio = Column(Float)
     thin_water_layer_definition = Column(Float)
-    use_of_cg = Column(Integer, nullable=False)
-    use_of_nested_newton = Column(Integer, nullable=False)
+    use_of_cg = Column(Integer)
+    use_of_nested_newton = Column(IntegerEnum(constants.OffOrStandard))
 
     global_settings = relationship("GlobalSetting", back_populates="numerical_settings")
 
@@ -398,20 +402,20 @@ class GlobalSetting(Base):
     manhole_storage_area = Column(Float)
     name = Column(String(128))
     sim_time_step = Column(Float, nullable=False)
-    output_time_step = Column(Float)
-    nr_timesteps = Column(Integer, nullable=False)
+    output_time_step = Column(Float, nullable=False)
+    nr_timesteps = Column(Integer)
     start_time = Column(Text)
-    start_date = Column(Text, nullable=False)
+    start_date = Column(Text)
     grid_space = Column(Float, nullable=False)
     dist_calc_points = Column(Float, nullable=False)
     kmax = Column(Integer, nullable=False)
     guess_dams = Column(Integer)
     table_step_size = Column(Float, nullable=False)
     flooding_threshold = Column(Float, nullable=False)
-    advection_1d = Column(Integer, nullable=False)
-    advection_2d = Column(Integer, nullable=False)
+    advection_1d = Column(IntegerEnum(constants.OffOrStandard), nullable=False)
+    advection_2d = Column(IntegerEnum(constants.OffOrStandard), nullable=False)
     dem_file = Column(String(255))
-    frict_type = Column(Integer)
+    frict_type = Column(IntegerEnum(constants.FrictionType), nullable=False)
     frict_coef = Column(Float, nullable=False)
     frict_coef_file = Column(String(255))
     water_level_ini_type = Column(IntegerEnum(constants.InitializationType))
@@ -425,11 +429,11 @@ class GlobalSetting(Base):
     epsg_code = Column(Integer)
     timestep_plus = Column(Boolean, nullable=False)
     max_angle_1d_advection = Column(Float)
-    minimum_sim_time_step = Column(Float)
+    minimum_sim_time_step = Column(Float, nullable=False)
     maximum_sim_time_step = Column(Float)
-    frict_avg = Column(Integer)
+    frict_avg = Column(IntegerEnum(constants.OffOrStandard), nullable=False)
     wind_shielding_file = Column(String(255))
-    use_0d_inflow = Column(IntegerEnum(constants.InflowType))
+    use_0d_inflow = Column(IntegerEnum(constants.InflowType), nullable=False)
     table_step_size_1d = Column(Float)
     table_step_size_volume_2d = Column(Float)
     use_2d_rain = Column(Integer, nullable=False)
@@ -480,7 +484,9 @@ class AggregationSettings(Base):
 
     var_name = Column(String(100), nullable=False)
     flow_variable = Column(VarcharEnum(constants.FlowVariable), nullable=False)
-    aggregation_method = Column(VarcharEnum(constants.AggregationMethod))
+    aggregation_method = Column(
+        VarcharEnum(constants.AggregationMethod), nullable=False
+    )
     timestep = Column(Integer, nullable=False)
 
 
